@@ -26,7 +26,7 @@ except ImportError:
     from io import StringIO
 
 
-__version__ = '0.2.5'
+__version__ = '0.2.6'
 
 
 def format_code(source,
@@ -216,32 +216,26 @@ def wrap_summary(summary, initial_indent, subsequent_indent, wrap_length):
 
 
 def open_with_encoding(filename, encoding, mode='r'):
-    """Open and return a file with a specific encoding."""
-    try:
-        # Python 3
-        return open(filename, mode=mode, encoding=encoding)
-    except TypeError:
-        return open(filename, mode=mode)
+    """Return opened file with a specific encoding."""
+    import io
+    return io.open(filename, mode=mode, encoding=encoding,
+                   newline='')  # Preserve line endings
 
 
 def detect_encoding(filename):
     """Return file encoding."""
     try:
-        # Python 3
-        try:
-            with open(filename, 'rb') as input_file:
-                encoding = tokenize.detect_encoding(input_file.readline)[0]
+        with open(filename, 'rb') as input_file:
+            from lib2to3.pgen2 import tokenize as lib2to3_tokenize
+            encoding = lib2to3_tokenize.detect_encoding(input_file.readline)[0]
 
-                # Check for correctness of encoding
-                import io
-                with io.TextIOWrapper(input_file, encoding) as wrapper:
-                    wrapper.read()
+            # Check for correctness of encoding.
+            with open_with_encoding(filename, encoding) as input_file:
+                input_file.read()
 
-            return encoding
-        except (SyntaxError, LookupError, UnicodeDecodeError):
-            return 'latin-1'
-    except AttributeError:
-        return 'utf-8'
+        return encoding
+    except (SyntaxError, LookupError, UnicodeDecodeError):
+        return 'latin-1'
 
 
 def main(argv, standard_out):
@@ -284,8 +278,8 @@ def main(argv, standard_out):
             else:
                 import difflib
                 diff = difflib.unified_diff(
-                    source.splitlines(True),
-                    formatted_source.splitlines(True),
+                    StringIO(source).readlines(),
+                    StringIO(formatted_source).readlines(),
                     'before/' + filename,
                     'after/' + filename)
                 standard_out.write(''.join(diff))
